# eric7.Plugins.VcsPlugins.vcsMercurial.StripExtension.strip

Module implementing the strip extension interface.

### Global Attributes

None

### Classes

Strip | Class implementing the strip extension interface.

### Functions

None

## Strip

Class implementing the strip extension interface.

### Derived from

HgExtension

### Class Attributes

None

### Class Methods

None

### Methods

Strip | Constructor
hgStrip | Public method to strip revisions from a repository.

### Static Methods

None

#### Strip (Constructor)

Strip(vcs)

Constructor

vcs (Hg)
  reference to the Mercurial vcs object

#### Strip.hgStrip

hgStrip(rev="")

Public method to strip revisions from a repository.

rev (str)
  revision to strip from

Return:
  flag indicating that the project should be reread

Return Type:
  bool

Up